You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shiro.apache.org by ad...@apache.org on 2009/06/18 05:13:47 UTC

svn commit: r785881 [8/11] - in /incubator/shiro/trunk: ./ all/ core/src/main/java/org/apache/ki/ core/src/main/java/org/apache/shiro/ core/src/main/java/org/apache/shiro/aop/ core/src/main/java/org/apache/shiro/authc/ core/src/main/java/org/apache/shi...

Modified: incubator/shiro/trunk/samples/spring/src/main/resources/ehcache.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/resources/ehcache.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/resources/ehcache.xml (original)
+++ incubator/shiro/trunk/samples/spring/src/main/resources/ehcache.xml Thu Jun 18 03:13:34 2009
@@ -17,7 +17,7 @@
   ~ under the License.
   -->
 
-<!-- EhCache XML configuration file used for Ki spring sample application -->
+<!-- EhCache XML configuration file used for Shiro spring sample application -->
 <ehcache>
 
   <!-- Sets the path to the directory where cache .data files are created.
@@ -29,7 +29,7 @@
 user.home - User's home directory
 user.dir - User's current working directory
 java.io.tmpdir - Default temp file path -->
-  <diskStore path="java.io.tmpdir/ki-spring-sample"/>
+  <diskStore path="java.io.tmpdir/shiro-spring-sample"/>
 
 
   <!--Default Cache configuration. These will applied to caches programmatically created through
@@ -74,22 +74,22 @@
     diskExpiryThreadIntervalSeconds="120"
     />
 
-  <!-- We want eternal="true" (with no timeToIdle or timeToLive settings) because Ki manages session
+  <!-- We want eternal="true" (with no timeToIdle or timeToLive settings) because Shiro manages session
 expirations explicitly.  If we set it to false and then set corresponding timeToIdle and timeToLive properties,
-ehcache would evict sessions without Ki's knowledge, which would cause many problems
-(e.g. "My Ki session timeout is 30 minutes - why isn't a session available after 2 minutes?"
+ehcache would evict sessions without Shiro's knowledge, which would cause many problems
+(e.g. "My Shiro session timeout is 30 minutes - why isn't a session available after 2 minutes?"
 Answer - ehcache expired it due to the timeToIdle property set to 120 seconds.)
 
 diskPersistent=true since we want an enterprise session management feature - ability to use sessions after
 even after a JVM restart.  -->
-  <cache name="ki-activeSessionCache"
+  <cache name="shiro-activeSessionCache"
          maxElementsInMemory="20000"
          eternal="true"
          overflowToDisk="true"
          diskPersistent="true"
          diskExpiryThreadIntervalSeconds="600"/>
 
-  <cache name="org.apache.ki.realm.SimpleAccountRealm.authorization"
+  <cache name="org.apache.shiro.realm.SimpleAccountRealm.authorization"
          maxElementsInMemory="100"
          eternal="false"
          timeToLiveSeconds="600"

Modified: incubator/shiro/trunk/samples/spring/src/main/resources/log4j.properties
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/resources/log4j.properties?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/resources/log4j.properties (original)
+++ incubator/shiro/trunk/samples/spring/src/main/resources/log4j.properties Thu Jun 18 03:13:34 2009
@@ -28,9 +28,9 @@
 # Spring
 log4j.logger.org.springframework=WARN
 
-# Default Ki logging
-log4j.logger.org.apache.ki=TRACE
+# Default Shiro logging
+log4j.logger.org.apache.shiro=TRACE
 
 # Disable verbose logging
-log4j.logger.org.apache.ki.util.ThreadContext=WARN
-log4j.logger.org.apache.ki.cache.ehcache.EhCache=WARN
+log4j.logger.org.apache.shiro.util.ThreadContext=WARN
+log4j.logger.org.apache.shiro.cache.ehcache.EhCache=WARN

Modified: incubator/shiro/trunk/samples/spring/src/main/resources/webstart.spring.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/resources/webstart.spring.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/resources/webstart.spring.xml (original)
+++ incubator/shiro/trunk/samples/spring/src/main/resources/webstart.spring.xml Thu Jun 18 03:13:34 2009
@@ -20,23 +20,23 @@
 <!DOCTYPE beans PUBLIC "-//SPRING//DTD BEAN//EN" "http://www.springframework.org/dtd/spring-beans.dtd">
 
 <!--
-  - Application context for Ki WebStart sample application
+  - Application context for Shiro WebStart sample application
   -->
 <beans>
 
   <bean id="webStartView"
-        class="org.apache.ki.samples.spring.ui.WebStartView">
+        class="org.apache.shiro.samples.spring.ui.WebStartView">
     <property name="sampleManager" ref="sampleManager"/>
   </bean>
 
   <bean id="sampleManager"
         class="org.springframework.remoting.httpinvoker.HttpInvokerProxyFactoryBean">
-    <property name="serviceUrl" value="http://localhost:8080/ki-spring/remoting/sampleManager"/>
-    <property name="serviceInterface" value="org.apache.ki.samples.spring.SampleManager"/>
+    <property name="serviceUrl" value="http://localhost:8080/shiro-spring/remoting/sampleManager"/>
+    <property name="serviceInterface" value="org.apache.shiro.samples.spring.SampleManager"/>
     <property name="remoteInvocationFactory" ref="secureRemoteInvocationFactory"/>
   </bean>
 
   <bean id="secureRemoteInvocationFactory"
-        class="org.apache.ki.spring.remoting.SecureRemoteInvocationFactory"/>
+        class="org.apache.shiro.spring.remoting.SecureRemoteInvocationFactory"/>
 
 </beans>

Modified: incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/applicationContext.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/applicationContext.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/applicationContext.xml (original)
+++ incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/applicationContext.xml Thu Jun 18 03:13:34 2009
@@ -21,40 +21,40 @@
 
 <beans>
 
-    <!-- Sample RDBMS data source that would exist in any application - not Ki related. -->
+    <!-- Sample RDBMS data source that would exist in any application - not Shiro related. -->
     <bean id="dataSource" class="org.springframework.jdbc.datasource.DriverManagerDataSource">
         <property name="driverClassName" value="org.hsqldb.jdbcDriver"/>
-        <property name="url" value="jdbc:hsqldb:mem:ki-spring"/>
+        <property name="url" value="jdbc:hsqldb:mem:shiro-spring"/>
         <property name="username" value="sa"/>
     </bean>
     <!-- Populates the sample database with sample users and roles. -->
-    <bean id="bootstrapDataPopulator" class="org.apache.ki.samples.spring.BootstrapDataPopulator">
+    <bean id="bootstrapDataPopulator" class="org.apache.shiro.samples.spring.BootstrapDataPopulator">
         <property name="dataSource" ref="dataSource"/>
     </bean>
 
-    <!-- Simulated business-tier "Manager", not Ki related, just an example -->
-    <bean id="sampleManager" class="org.apache.ki.samples.spring.DefaultSampleManager"/>
+    <!-- Simulated business-tier "Manager", not Shiro related, just an example -->
+    <bean id="sampleManager" class="org.apache.shiro.samples.spring.DefaultSampleManager"/>
 
     <!-- =========================================================
-         Ki Core Components - Not Spring Specific
+         Shiro Core Components - Not Spring Specific
          ========================================================= -->
-    <!-- Ki's main business-tier object for web-enabled applications
+    <!-- Shiro's main business-tier object for web-enabled applications
          (use DefaultSecurityManager instead when there is no web environment)-->
-    <bean id="securityManager" class="org.apache.ki.web.DefaultWebSecurityManager">
+    <bean id="securityManager" class="org.apache.shiro.web.DefaultWebSecurityManager">
         <!-- Single realm app.  If you have multiple realms, use the 'realms' property instead. -->
         <property name="realm" ref="jdbcRealm"/>
-        <property name="sessionMode" value="ki"/>
+        <property name="sessionMode" value="shiro"/>
     </bean>
 
     <!-- Used by the SecurityManager to access security data (users, roles, etc).
          Many other realm implementations can be used too (PropertiesRealm,
          LdapRealm, etc. -->
-    <bean id="jdbcRealm" class="org.apache.ki.realm.jdbc.JdbcRealm">
+    <bean id="jdbcRealm" class="org.apache.shiro.realm.jdbc.JdbcRealm">
         <property name="dataSource" ref="dataSource"/>
         <property name="credentialsMatcher">
             <!-- The 'bootstrapDataPopulator' Sha256 hashes the password
                  (using the username as the salt) then base64 encodes it: -->
-            <bean class="org.apache.ki.authc.credential.Sha256CredentialsMatcher">
+            <bean class="org.apache.shiro.authc.credential.Sha256CredentialsMatcher">
                 <!-- true means hex encoded, false means base64 encoded -->
                 <property name="storedCredentialsHexEncoded" value="false"/>
                 <!-- We salt the password using the username, the most common practice: -->
@@ -64,27 +64,27 @@
     </bean>
 
     <!-- =========================================================
-         Ki Spring-specific integration
+         Shiro Spring-specific integration
          ========================================================= -->
     <!-- Post processor that automatically invokes init() and destroy() methods
-         for Spring-configured Ki objects so you don't have to
+         for Spring-configured Shiro objects so you don't have to
          1) specify an init-method and destroy-method attributes for every bean
             definition and
-         2) even know which Ki objects require these methods to be
+         2) even know which Shiro objects require these methods to be
             called. -->
-    <bean id="lifecycleBeanPostProcessor" class="org.apache.ki.spring.LifecycleBeanPostProcessor"/>
+    <bean id="lifecycleBeanPostProcessor" class="org.apache.shiro.spring.LifecycleBeanPostProcessor"/>
 
-    <!-- Enable Ki Annotations for Spring-configured beans.  Only run after
+    <!-- Enable Shiro Annotations for Spring-configured beans.  Only run after
          the lifecycleBeanProcessor has run: -->
     <bean class="org.springframework.aop.framework.autoproxy.DefaultAdvisorAutoProxyCreator"
           depends-on="lifecycleBeanPostProcessor"/>
-    <bean class="org.apache.ki.spring.security.interceptor.AuthorizationAttributeSourceAdvisor">
+    <bean class="org.apache.shiro.spring.security.interceptor.AuthorizationAttributeSourceAdvisor">
         <property name="securityManager" ref="securityManager"/>
     </bean>
 
     <!-- Secure Spring remoting:  Ensure any Spring Remoting method invocations can be associated
          with a Subject for security checks. -->
-    <bean id="secureRemoteInvocationExecutor" class="org.apache.ki.spring.remoting.SecureRemoteInvocationExecutor">
+    <bean id="secureRemoteInvocationExecutor" class="org.apache.shiro.spring.remoting.SecureRemoteInvocationExecutor">
         <property name="securityManager" ref="securityManager"/>
     </bean>
 

Modified: incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/remoting-servlet.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/remoting-servlet.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/remoting-servlet.xml (original)
+++ incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/remoting-servlet.xml Thu Jun 18 03:13:34 2009
@@ -26,7 +26,7 @@
 
     <bean name="/sampleManager" class="org.springframework.remoting.httpinvoker.HttpInvokerServiceExporter">
         <property name="service" ref="sampleManager"/>
-        <property name="serviceInterface" value="org.apache.ki.samples.spring.SampleManager"/>
+        <property name="serviceInterface" value="org.apache.shiro.samples.spring.SampleManager"/>
         <property name="remoteInvocationExecutor" ref="secureRemoteInvocationExecutor"/>
     </bean>
 

Modified: incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/include.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/include.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/include.jsp (original)
+++ incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/include.jsp Thu Jun 18 03:13:34 2009
@@ -21,4 +21,4 @@
 <%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
 <%@ taglib prefix="fmt" uri="http://java.sun.com/jsp/jstl/fmt" %>
 <%@ taglib prefix="spring" uri="http://www.springframework.org/tags" %>
-<%@ taglib prefix="ki" uri="http://ki.apache.org/tags" %>
\ No newline at end of file
+<%@ taglib prefix="shiro" uri="http://shiro.apache.org/tags" %>
\ No newline at end of file

Modified: incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/login.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/login.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/login.jsp (original)
+++ incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/login.jsp Thu Jun 18 03:13:34 2009
@@ -21,14 +21,14 @@
 <html>
 
 <head>
-    <link type="text/css" rel="stylesheet" href="<c:url value="/ki.css"/>"/>
+    <link type="text/css" rel="stylesheet" href="<c:url value="/shiro.css"/>"/>
 </head>
 
 <body onload="document.forms[0].elements[0].focus();">
 
 <div id="contentBox">
 
-    <h1>Ki Login</h1>
+    <h1>Shiro Login</h1>
 
     <p>
         <span style="color: red;">

Modified: incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/sampleIndex.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/sampleIndex.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/sampleIndex.jsp (original)
+++ incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/sampleIndex.jsp Thu Jun 18 03:13:34 2009
@@ -21,7 +21,7 @@
 <html>
 
 <head>
-    <link type="text/css" rel="stylesheet" href="<c:url value="/ki.css"/>"/>
+    <link type="text/css" rel="stylesheet" href="<c:url value="/shiro.css"/>"/>
 </head>
 
 <body>
@@ -29,7 +29,7 @@
 <div id="contentBox">
     <img src="<c:url value="/logo.png"/>" style="margin-top:20px; border:0"/><br/>
 
-    <h2>You have successfully logged in as <ki:principal/>.</h2>
+    <h2>You have successfully logged in as <shiro:principal/>.</h2>
 
     Session ID: ${subjectSession.id}
 
@@ -41,17 +41,17 @@
     </ul>
 
     <p style="font-weight: bold;">
-        <ki:hasRole name="role1">You have role 1.<br/></ki:hasRole>
-        <ki:lacksRole name="role1">You do not have role 1.<br/></ki:lacksRole>
-        <ki:hasRole name="role2">You have role 2.<br/></ki:hasRole>
-        <ki:lacksRole name="role2">You do not have role 2.<br/></ki:lacksRole>
+        <shiro:hasRole name="role1">You have role 1.<br/></shiro:hasRole>
+        <shiro:lacksRole name="role1">You do not have role 1.<br/></shiro:lacksRole>
+        <shiro:hasRole name="role2">You have role 2.<br/></shiro:hasRole>
+        <shiro:lacksRole name="role2">You do not have role 2.<br/></shiro:lacksRole>
     </p>
 
     <p style="font-weight: bold;">
-        <ki:hasPermission name="permission1">You have permission 1.<br/></ki:hasPermission>
-        <ki:lacksPermission name="permission1">You do not have permission 1.<br/></ki:lacksPermission>
-        <ki:hasPermission name="permission2">You have permission 2.<br/></ki:hasPermission>
-        <ki:lacksPermission name="permission2">You do not have permission 2.<br/></ki:lacksPermission>
+        <shiro:hasPermission name="permission1">You have permission 1.<br/></shiro:hasPermission>
+        <shiro:lacksPermission name="permission1">You do not have permission 1.<br/></shiro:lacksPermission>
+        <shiro:hasPermission name="permission2">You have permission 2.<br/></shiro:hasPermission>
+        <shiro:lacksPermission name="permission2">You do not have permission 2.<br/></shiro:lacksPermission>
     </p>
 
 
@@ -63,7 +63,7 @@
 
 
     <p>
-        Click <a href="<c:url value="/s/ki.jnlp?sessionId=${subjectSession.id}"/>">here</a> to launch webstart
+        Click <a href="<c:url value="/s/shiro.jnlp?sessionId=${subjectSession.id}"/>">here</a> to launch webstart
         application.
     </p>
 

Copied: incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/shiro.jnlp.jsp (from r785781, incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/ki.jnlp.jsp)
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/shiro.jnlp.jsp?p2=incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/shiro.jnlp.jsp&p1=incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/ki.jnlp.jsp&r1=785781&r2=785881&rev=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/ki.jnlp.jsp (original)
+++ incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/resources/shiro.jnlp.jsp Thu Jun 18 03:13:34 2009
@@ -19,14 +19,14 @@
 <%@ page contentType="application/x-java-jnlp-file" %>
 
 <?xml version="1.0" encoding="utf-8"?>
-<!-- JNLP File for Ki Sample Application -->
+<!-- JNLP File for Shiro Sample Application -->
 <jnlp spec="1.0+" codebase="${codebaseUrl}">
     <information>
-        <title>Apache Ki Sample Application</title>
-        <vendor>Apache Ki</vendor>
-        <homepage href="http://ki.apache.org"/>
-        <description>Apache Ki Sample Application</description>
-        <description kind="short">A webstart application used to demonstrate Apache Ki session and security
+        <title>Apache Shiro Sample Application</title>
+        <vendor>Apache Shiro</vendor>
+        <homepage href="http://shiro.apache.org"/>
+        <description>Apache Shiro Sample Application</description>
+        <description kind="short">A webstart application used to demonstrate Apache Shiro session and security
             management.
         </description>
         <icon kind="splash" href="logo.png"/>
@@ -37,11 +37,11 @@
     </security>
     <resources>
         <j2se version="1.5"/>
-        <jar href="ki-spring-sample.jar"/>
-        <jar href="ki-all.jar"/>
+        <jar href="shiro-spring-sample.jar"/>
+        <jar href="shiro-all.jar"/>
         <jar href="spring.jar"/>
         <jar href="slf4j-api.jar"/>
-        <property name="ki.session.id" value="${sessionId}"/>
+        <property name="shiro.session.id" value="${sessionId}"/>
     </resources>
-    <application-desc main-class="org.apache.ki.samples.spring.ui.WebStartDriver"/>
+    <application-desc main-class="org.apache.shiro.samples.spring.ui.WebStartDriver"/>
 </jnlp>

Modified: incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/sample-servlet.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/sample-servlet.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/sample-servlet.xml (original)
+++ incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/sample-servlet.xml Thu Jun 18 03:13:34 2009
@@ -29,7 +29,7 @@
         <property name="mappings">
             <props>
                 <prop key="index">indexController</prop>
-                <prop key="ki.jnlp">jnlpController</prop>
+                <prop key="shiro.jnlp">jnlpController</prop>
                 <prop key="login">loginController</prop>
                 <prop key="logout">logoutController</prop>
                 <prop key="unauthorized">loginController</prop>
@@ -46,21 +46,21 @@
     <!-- =========================================================
          Spring controllers
          ========================================================= -->
-    <bean name="loginController" class="org.apache.ki.samples.spring.web.LoginController">
-        <property name="commandClass" value="org.apache.ki.samples.spring.web.LoginCommand"/>
+    <bean name="loginController" class="org.apache.shiro.samples.spring.web.LoginController">
+        <property name="commandClass" value="org.apache.shiro.samples.spring.web.LoginCommand"/>
         <property name="formView" value="login"/>
         <property name="successView" value="redirect:/s/index"/>
         <property name="securityManager" ref="securityManager"/>
     </bean>
 
-    <bean name="logoutController" class="org.apache.ki.samples.spring.web.LogoutController"/>
+    <bean name="logoutController" class="org.apache.shiro.samples.spring.web.LogoutController"/>
 
-    <bean id="jnlpController" class="org.apache.ki.samples.spring.web.JnlpController">
-        <property name="jnlpView" value="ki.jnlp"/>
+    <bean id="jnlpController" class="org.apache.shiro.samples.spring.web.JnlpController">
+        <property name="jnlpView" value="shiro.jnlp"/>
     </bean>
 
-    <bean id="indexController" class="org.apache.ki.samples.spring.web.IndexController">
-        <property name="commandClass" value="org.apache.ki.samples.spring.web.SessionValueCommand"/>
+    <bean id="indexController" class="org.apache.shiro.samples.spring.web.IndexController">
+        <property name="commandClass" value="org.apache.shiro.samples.spring.web.SessionValueCommand"/>
         <property name="formView" value="sampleIndex"/>
         <property name="successView" value="sampleIndex"/>
         <property name="sampleManager" ref="sampleManager"/>

Modified: incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/web.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/web.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/web.xml (original)
+++ incubator/shiro/trunk/samples/spring/src/main/webapp/WEB-INF/web.xml Thu Jun 18 03:13:34 2009
@@ -57,7 +57,7 @@
          ================================================================== -->
     <filter>
         <filter-name>KiFilter</filter-name>
-        <filter-class>org.apache.ki.spring.SpringKiFilter</filter-class>
+        <filter-class>org.apache.shiro.spring.SpringShiroFilter</filter-class>
 
         <init-param>
             <param-name>config</param-name>
@@ -65,15 +65,15 @@
                 # The KiFilter configuration is very powerful and flexible, while still remaining succinct.
                 # Please read the comprehensive example, with full comments and explanations, in the JavaDoc:
                 #
-                # http://ki.apache.org/api/org/apache/ki/web/servlet/KiFilter.html
+                # http://shiro.apache.org/api/org/apache/shiro/web/servlet/KiFilter.html
 
                 [filters]
-                ki.loginUrl = /s/login
+                shiro.loginUrl = /s/login
                 authc.successUrl = /s/index
 
                 [urls]
                 /s/index=authc
-                /s/ki.jnlp=authc,user
+                /s/shiro.jnlp=authc,user
                 /remoting/**=authc, perms[remote:invoke]
             </param-value>
         </init-param>

Modified: incubator/shiro/trunk/samples/standalone/src/main/java/MyRealm.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/standalone/src/main/java/MyRealm.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/standalone/src/main/resources/log4j.properties (original)
+++ incubator/shiro/trunk/samples/standalone/src/main/resources/log4j.properties Thu Jun 18 03:13:34 2009
@@ -28,10 +28,10 @@
 # Spring
 log4j.logger.org.springframework=WARN
 
-# Default Ki logging
-log4j.logger.org.ki=TRACE
+# Default Shiro logging
+log4j.logger.org.shiro=TRACE
 
 # Disable verbose logging
-log4j.logger.org.apache.ki.util.ThreadContext=WARN
-log4j.logger.org.apache.ki.cache.ehcache.EhCache=WARN
+log4j.logger.org.apache.shiro.util.ThreadContext=WARN
+log4j.logger.org.apache.shiro.cache.ehcache.EhCache=WARN
 

Copied: incubator/shiro/trunk/samples/standalone/src/main/resources/shiro.ini (from r785781, incubator/shiro/trunk/samples/standalone/src/main/resources/ki.ini)
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/standalone/src/main/resources/shiro.ini?p2=incubator/shiro/trunk/samples/standalone/src/main/resources/shiro.ini&p1=incubator/shiro/trunk/samples/standalone/src/main/resources/ki.ini&r1=785781&r2=785881&rev=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/standalone/src/main/resources/ki.ini (original)
+++ incubator/shiro/trunk/samples/standalone/src/main/resources/shiro.ini Thu Jun 18 03:13:34 2009
@@ -27,7 +27,7 @@
 # This simple example uses only a single realm, but you could add more for more complicated requirements.
 
 # We'll use credentials hashing, since that keeps the users' credentials (passwords, private keys, etc) safe:
-myRealmCredentialsMatcher = org.apache.ki.authc.credential.Sha256CredentialsMatcher
+myRealmCredentialsMatcher = org.apache.shiro.authc.credential.Sha256CredentialsMatcher
 
 # now define the realm, and specify that it use the above credentials matcher:
 myRealm = MyRealm

Modified: incubator/shiro/trunk/samples/web/src/main/resources/log4j.properties
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/web/src/main/resources/log4j.properties?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/web/src/main/resources/log4j.properties (original)
+++ incubator/shiro/trunk/samples/web/src/main/resources/log4j.properties Thu Jun 18 03:13:34 2009
@@ -37,11 +37,11 @@
 log4j.logger.org.quartz=WARN
 
 # =============================================================================
-# Apache Ki
+# Apache Shiro
 # =============================================================================
-# Ki security framework
-log4j.logger.org.apache.ki.realm.text.PropertiesRealm=INFO
-log4j.logger.org.apache.ki.cache.ehcache.EhCache=INFO
-log4j.logger.org.apache.ki.io=INFO
-log4j.logger.org.apache.ki.web.servlet=INFO
-log4j.logger.org.apache.ki.util.ThreadContext=INFO
+# Shiro security framework
+log4j.logger.org.apache.shiro.realm.text.PropertiesRealm=INFO
+log4j.logger.org.apache.shiro.cache.ehcache.EhCache=INFO
+log4j.logger.org.apache.shiro.io=INFO
+log4j.logger.org.apache.shiro.web.servlet=INFO
+log4j.logger.org.apache.shiro.util.ThreadContext=INFO

Modified: incubator/shiro/trunk/samples/web/src/main/webapp/WEB-INF/web.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/web/src/main/webapp/WEB-INF/web.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/web/src/main/webapp/WEB-INF/web.xml (original)
+++ incubator/shiro/trunk/samples/web/src/main/webapp/WEB-INF/web.xml Thu Jun 18 03:13:34 2009
@@ -24,7 +24,7 @@
 
     <filter>
         <filter-name>KiFilter</filter-name>
-        <filter-class>org.apache.ki.web.servlet.KiFilter</filter-class>
+        <filter-class>org.apache.shiro.web.servlet.ShiroFilter</filter-class>
         <init-param>
             <param-name>config</param-name>
             <param-value>
@@ -32,20 +32,20 @@
                 # The KiFilter configuration is very powerful and flexible, while still remaining succinct.
                 # Please read the comprehensive example, with full comments and explanations, in the JavaDoc:
                 #
-                # http://ki.apache.org/api/org/apache/ki/web/servlet/KiFilter.html
+                # http://shiro.apache.org/api/org/apache/shiro/web/servlet/KiFilter.html
 
                 [main]
 
-                demoRealm = org.apache.ki.realm.text.PropertiesRealm
+                demoRealm = org.apache.shiro.realm.text.PropertiesRealm
 
                 [filters]
-                ki.loginUrl = /login.jsp
+                shiro.loginUrl = /login.jsp
 
                 [urls]
                 # The /login.jsp is not restricted to authenticated users (otherwise no one could log in!), but
                 # the 'authc' filter must still be specified for it so it can process that url's
                 # login submissions. It is 'smart' enough to allow those requests through as specified by the
-                # ki.loginUrl above.
+                # shiro.loginUrl above.
                 /login.jsp = authc
 
                 /account/** = authc

Modified: incubator/shiro/trunk/samples/web/src/main/webapp/home.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/web/src/main/webapp/home.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/web/src/main/webapp/home.jsp (original)
+++ incubator/shiro/trunk/samples/web/src/main/webapp/home.jsp Thu Jun 18 03:13:34 2009
@@ -24,19 +24,19 @@
 </head>
 <body>
 
-<h1>Apache Ki Quickstart</h1>
+<h1>Apache Shiro Quickstart</h1>
 
-<p>Hi <ki:guest>Guest</ki:guest><ki:user><ki:principal/></ki:user>!
-    ( <ki:user><a href="<c:url value="/logout.jsp"/>">Log out</a></ki:user>
-    <ki:guest><a href="<c:url value="/login.jsp"/>">Log in</a> (sample accounts provided)</ki:guest> )
+<p>Hi <shiro:guest>Guest</shiro:guest><shiro:user><shiro:principal/></shiro:user>!
+    ( <shiro:user><a href="<c:url value="/logout.jsp"/>">Log out</a></shiro:user>
+    <shiro:guest><a href="<c:url value="/login.jsp"/>">Log in</a> (sample accounts provided)</shiro:guest> )
 </p>
 
-<p>Welcome to the Apache Ki Quickstart sample application.
+<p>Welcome to the Apache Shiro Quickstart sample application.
     This page represents the home page of any web application.</p>
 
-<ki:user><p>Visit your <a href="<c:url value="/account"/>">account page</a>.</p></ki:user>
-<ki:guest><p>If you want to access the user-only <a href="<c:url value="/account"/>">account page</a>,
-    you will need to log-in first.</p></ki:guest>
+<shiro:user><p>Visit your <a href="<c:url value="/account"/>">account page</a>.</p></shiro:user>
+<shiro:guest><p>If you want to access the user-only <a href="<c:url value="/account"/>">account page</a>,
+    you will need to log-in first.</p></shiro:guest>
 
 <h2>Roles</h2>
 
@@ -46,21 +46,21 @@
 <h3>Roles you have</h3>
 
 <p>
-    <ki:hasRole name="root">root<br/></ki:hasRole>
-    <ki:hasRole name="president">president<br/></ki:hasRole>
-    <ki:hasRole name="darklord">darklord<br/></ki:hasRole>
-    <ki:hasRole name="goodguy">goodguy<br/></ki:hasRole>
-    <ki:hasRole name="schwartz">schwartz<br/></ki:hasRole>
+    <shiro:hasRole name="root">root<br/></shiro:hasRole>
+    <shiro:hasRole name="president">president<br/></shiro:hasRole>
+    <shiro:hasRole name="darklord">darklord<br/></shiro:hasRole>
+    <shiro:hasRole name="goodguy">goodguy<br/></shiro:hasRole>
+    <shiro:hasRole name="schwartz">schwartz<br/></shiro:hasRole>
 </p>
 
 <h3>Roles you DON'T have</h3>
 
 <p>
-    <ki:lacksRole name="root">root<br/></ki:lacksRole>
-    <ki:lacksRole name="president">president<br/></ki:lacksRole>
-    <ki:lacksRole name="darklord">darklord<br/></ki:lacksRole>
-    <ki:lacksRole name="goodguy">goodguy<br/></ki:lacksRole>
-    <ki:lacksRole name="schwartz">schwartz<br/></ki:lacksRole>
+    <shiro:lacksRole name="root">root<br/></shiro:lacksRole>
+    <shiro:lacksRole name="president">president<br/></shiro:lacksRole>
+    <shiro:lacksRole name="darklord">darklord<br/></shiro:lacksRole>
+    <shiro:lacksRole name="goodguy">goodguy<br/></shiro:lacksRole>
+    <shiro:lacksRole name="schwartz">schwartz<br/></shiro:lacksRole>
 </p>
 
 

Modified: incubator/shiro/trunk/samples/web/src/main/webapp/include.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/web/src/main/webapp/include.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/web/src/main/webapp/include.jsp (original)
+++ incubator/shiro/trunk/samples/web/src/main/webapp/include.jsp Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
   ~ specific language governing permissions and limitations
   ~ under the License.
   --%>
-<%@ page import="org.apache.ki.SecurityUtils" %>
+<%@ page import="org.apache.shiro.SecurityUtils" %>
 <%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
 <%@ taglib prefix="fmt" uri="http://java.sun.com/jsp/jstl/fmt" %>
-<%@ taglib prefix="ki" uri="http://ki.apache.org/tags" %>
\ No newline at end of file
+<%@ taglib prefix="shiro" uri="http://shiro.apache.org/tags" %>
\ No newline at end of file

Modified: incubator/shiro/trunk/samples/web/src/main/webapp/login.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/web/src/main/webapp/login.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/web/src/main/webapp/login.jsp (original)
+++ incubator/shiro/trunk/samples/web/src/main/webapp/login.jsp Thu Jun 18 03:13:34 2009
@@ -26,7 +26,7 @@
 
 <h2>Please Log in</h2>
 
-<ki:guest>
+<shiro:guest>
     <p>Here are a few sample accounts to play with in the default text-based Realm (used for this
         demo and test installs only). Do you remember the movie these names came from? ;)</p>
 
@@ -85,7 +85,7 @@
         </tbody>
     </table>
     <br/><br/>
-</ki:guest>
+</shiro:guest>
 
 <form action="" method="post">
     <table align="left" border="0" cellspacing="0" cellpadding="3">

Modified: incubator/shiro/trunk/samples/web/src/main/webapp/logout.jsp
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/web/src/main/webapp/logout.jsp?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/web/src/main/webapp/logout.jsp (original)
+++ incubator/shiro/trunk/samples/web/src/main/webapp/logout.jsp Thu Jun 18 03:13:34 2009
@@ -1,4 +1,4 @@
-<%@ page import="org.apache.ki.SecurityUtils" %>
+<%@ page import="org.apache.shiro.SecurityUtils" %>
 <%--
 ~ Licensed to the Apache Software Foundation (ASF) under one
 ~ or more contributor license agreements.  See the NOTICE file
@@ -30,7 +30,7 @@
 
       When a user logs out, any 'rememberMe' identity
       should always be cleared.  In a web application,
-      Ki uses a Cipher-encrypted Cookie to
+      Shiro uses a Cipher-encrypted Cookie to
       remember a user's identity by default, and it will
       automatically delete the Cookie upon a logout.
 

Modified: incubator/shiro/trunk/src/docbkx/index.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/src/docbkx/index.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/src/docbkx/index.xml (original)
+++ incubator/shiro/trunk/src/docbkx/index.xml Thu Jun 18 03:13:34 2009
@@ -17,13 +17,13 @@
   ~ specific language governing permissions and limitations
   ~ under the License.
   -->
-<book version="5.0" xml:id="apache-ki-reference-documentation"
+<book version="5.0" xml:id="apache-shiro-reference-documentation"
       xmlns="http://docbook.org/ns/docbook"
       xmlns:xlink="http://www.w3.org/1999/xlink"
       xmlns:xi="http://www.w3.org/2001/XInclude">
 
     <info>
-        <title>Apache Ki</title>
+        <title>Apache Shiro</title>
         <subtitle>Reference Documentation</subtitle>
         <authorgroup>
             <author>
@@ -64,14 +64,14 @@
 
     <xi:include href="preface.xml"/>
 
-    <part xml:id="ki-quickstart">
-        <title>Apache Ki Quickstart</title>
-        <partintro xml:id="ki-quickstart-intro">
+    <part xml:id="shiro-quickstart">
+        <title>Apache Shiro Quickstart</title>
+        <partintro xml:id="shiro-quickstart-intro">
             <para>
                 This initial part of the reference documentation walks through the simplest quickstart application
-                so that you may become familiarized Ki's programming API and general concepts. While this
-                application is probably the absolute simplest Ki-enabled application that we know of,
-                it should make you comfortable understanding what Ki can do, and how it can help you create
+                so that you may become familiarized Shiro's programming API and general concepts. While this
+                application is probably the absolute simplest Shiro-enabled application that we know of,
+                it should make you comfortable understanding what Shiro can do, and how it can help you create
                 more secure applications. The rest of the documentation will serve as your guide to help you move
                 from this simple example to even the most complicated enterprise applications.
             </para>
@@ -85,12 +85,12 @@
             </note>
         </partintro>
     </part>
-    <part xml:id="ki-core">
-        <title>Apache Ki Core</title>
-        <partintro xml:id="ki-core-intro">
+    <part xml:id="shiro-core">
+        <title>Apache Shiro Core</title>
+        <partintro xml:id="shiro-core-intro">
             <para>
                 This part of the reference documentation covers
-                Ki's core architectural components that support
+                Shiro's core architectural components that support
                 functionality in all environments, from
                 constrained Applets and cell phones to full n-tier
                 clustered enterprise applications.
@@ -147,12 +147,12 @@
         <xi:include href="security-manager.xml"/>
     </part>
 
-    <!-- <part xml:id="ki-web">
+    <!-- <part xml:id="shiro-web">
      <title>Web Support</title>
-     <partintro xml:id="ki-web-intro">
+     <partintro xml:id="shiro-web-intro">
        <para>
          This part of the reference documentation covers
-                 Ki's web support, specifically using Ki in
+                 Shiro's web support, specifically using Shiro in
                  a Servlet container for web-based applications.
        </para>
        <para>
@@ -188,11 +188,11 @@
      &web-integration;
      &portlet;
    </part>
-   <part id="ki-integration">
+   <part id="shiro-integration">
      <title>Integration</title>
-     <partintro id="ki-integration-intro">
+     <partintro id="shiro-integration-intro">
        <para>
-         This part of the reference documentation covers Ki's
+         This part of the reference documentation covers Shiro's
                  integration with other technologies that might be
                  useful in application deployments.
        </para>
@@ -228,5 +228,5 @@
      </partintro>
    </part> -->
     <!-- back matter -->
-    <!-- <xi:include href="ki.tld.xml"/> -->
+    <!-- <xi:include href="shiro.tld.xml"/> -->
 </book>

Modified: incubator/shiro/trunk/src/docbkx/preface.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/src/docbkx/preface.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/src/docbkx/preface.xml (original)
+++ incubator/shiro/trunk/src/docbkx/preface.xml Thu Jun 18 03:13:34 2009
@@ -43,7 +43,7 @@
     </para>
 
     <para>
-        Apache Ki is a Java security framework that attempts to achieve these goals. The framework tries to
+        Apache Shiro is a Java security framework that attempts to achieve these goals. The framework tries to
         give as much power and flexibility as possible, while still being
         <emphasis>really</emphasis>
         easy to understand and easy to use. It tries to be the most comprehensive and feature-rich security
@@ -51,8 +51,8 @@
     </para>
 
     <para>
-        This document is the official refrence manual for the Apache Ki framework, and it aims to give you the
-        most complete documentation on Ki and all of its features. It is
+        This document is the official refrence manual for the Apache Shiro framework, and it aims to give you the
+        most complete documentation on Shiro and all of its features. It is
         very much a work-in-progress, and we welcome suggestions and recommendations. If you have any,
         we'd very much appreciate your feedback on our forums at
         <link href="http://www.jsecurity.org/forum">http://www.jsecurity.org/forum</link>
@@ -76,7 +76,7 @@
 
     <para>
         So, without further adieu, let's move on to the documentation. Feel
-        free knowing you can incorporate Ki's rich features quickly and easily now, or perhaps maybe
+        free knowing you can incorporate Shiro's rich features quickly and easily now, or perhaps maybe
         later when you<quote>get around to it</quote>.
     </para>
 

Modified: incubator/shiro/trunk/src/docbkx/resources/xsl/fopdf.xsl
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/src/docbkx/resources/xsl/fopdf.xsl?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/src/docbkx/resources/xsl/fopdf.xsl (original)
+++ incubator/shiro/trunk/src/docbkx/resources/xsl/fopdf.xsl Thu Jun 18 03:13:34 2009
@@ -20,7 +20,7 @@
   -->
 
 <!--
-    This is the XSL FO (PDF) stylesheet for the Apache Ki reference
+    This is the XSL FO (PDF) stylesheet for the Apache Shiro reference
     documentation.
 
     Thanks are due to Christian Bauer of the Hibernate project team
@@ -119,7 +119,7 @@
         <xsl:param name="gentext-key" select="''"/>
         <xsl:variable name="Version">
             <xsl:if test="//releaseinfo">
-                <xsl:text>Apache Ki (</xsl:text>
+                <xsl:text>Apache Shiro (</xsl:text>
                 <xsl:value-of select="//releaseinfo"/>
                 <xsl:text>)</xsl:text>
             </xsl:if>

Modified: incubator/shiro/trunk/src/docbkx/resources/xsl/html.xsl
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/src/docbkx/resources/xsl/html.xsl?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/src/docbkx/resources/xsl/html.xsl (original)
+++ incubator/shiro/trunk/src/docbkx/resources/xsl/html.xsl Thu Jun 18 03:13:34 2009
@@ -19,7 +19,7 @@
   -->
 
 <!--
-    This is the XSL HTML configuration file for the Apache Ki
+    This is the XSL HTML configuration file for the Apache Shiro
     Reference Documentation.
 -->
 <xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"

Modified: incubator/shiro/trunk/src/docbkx/resources/xsl/html_chunk.xsl
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/src/docbkx/resources/xsl/html_chunk.xsl?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/src/docbkx/resources/xsl/html_chunk.xsl (original)
+++ incubator/shiro/trunk/src/docbkx/resources/xsl/html_chunk.xsl Thu Jun 18 03:13:34 2009
@@ -19,7 +19,7 @@
   -->
 
 <!--
-    This is the XSL HTML configuration file for the Apache Ki Reference Documentation.
+    This is the XSL HTML configuration file for the Apache Shiro Reference Documentation.
 -->
 <xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                 xmlns:fo="http://www.w3.org/1999/XSL/Format"
@@ -99,10 +99,10 @@
     <!--###################################################
                     Headers and Footers
    ################################################### -->
-    <!-- let's have a Ki and Anjin banner across the top of each page -->
+    <!-- let's have a Shiro and Anjin banner across the top of each page -->
     <xsl:template name="user.header.navigation">
         <div style="background-color:white;border:none;height:73px;border:1px solid black;">
-            <a style="border:none;" href="http://www.jsecurity.org/" title="Apache Ki">
+            <a style="border:none;" href="http://www.jsecurity.org/" title="Apache Shiro">
                 <img style="border:none;" src="images/xdev-jsecurity_logo.jpg"/>
             </a>
             <!--  <a style="border:none;" href="http://www.anjinllc.com/" title="AnjinLLC">

Modified: incubator/shiro/trunk/src/docbkx/resources/xsl/tld.to.docbook.xsl
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/src/docbkx/resources/xsl/tld.to.docbook.xsl?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/src/docbkx/resources/xsl/tld.to.docbook.xsl (original)
+++ incubator/shiro/trunk/src/docbkx/resources/xsl/tld.to.docbook.xsl Thu Jun 18 03:13:34 2009
@@ -55,9 +55,9 @@
       </xsl:element>
 
       <xsl:element name="para">
-        <xsl:text>One of the view technologies you can use with Ki
+        <xsl:text>One of the view technologies you can use with Shiro
           is Java Server Pages (JSPs). To help you implement views using Java Server Pages,
-          Ki provides you with some tags for evaluating errors, setting
+          Shiro provides you with some tags for evaluating errors, setting
           themes and outputting internationalized messages.
         </xsl:text>
       </xsl:element>

Modified: incubator/shiro/trunk/src/docbkx/security-manager.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/src/docbkx/security-manager.xml?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/src/docbkx/security-manager.xml (original)
+++ incubator/shiro/trunk/src/docbkx/security-manager.xml Thu Jun 18 03:13:34 2009
@@ -26,7 +26,7 @@
   <section xml:id="security-manager-introduction">
     <title>Introduction</title>
 
-    <para>This chapter covers Ki's notion of a Security Manager.</para>
+    <para>This chapter covers Shiro's notion of a Security Manager.</para>
 
   </section>
 

Modified: incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/EhCache.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/EhCache.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/package-info.java (original)
+++ incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,7 +17,7 @@
  * under the License.
  */
 /**
- * <a href="http://ehcache.sourceforge.net" target="_top">Ehcache</a>-based implementations of Ki's
+ * <a href="http://ehcache.sourceforge.net" target="_top">Ehcache</a>-based implementations of Shiro's
  * cache interfaces.
  */
-package org.apache.ki.cache.ehcache;
+package org.apache.shiro.cache.ehcache;

Modified: incubator/shiro/trunk/support/ehcache/src/main/resources/org/apache/shiro/cache/ehcache/ehcache.xml
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/ehcache/src/main/resources/org/apache/shiro/cache/ehcache/ehcache.xml?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/ehcache/src/main/resources/org/apache/shiro/cache/ehcache/ehcache.xml (original)
+++ incubator/shiro/trunk/support/ehcache/src/main/resources/org/apache/shiro/cache/ehcache/ehcache.xml Thu Jun 18 03:13:34 2009
@@ -27,7 +27,7 @@
 user.home - User's home directory
 user.dir - User's current working directory
 java.io.tmpdir - Default temp file path -->
-    <diskStore path="java.io.tmpdir/ki-ehcache"/>
+    <diskStore path="java.io.tmpdir/shiro-ehcache"/>
 
 
     <!--Default Cache configuration. These will applied to caches programmatically created through
@@ -72,22 +72,22 @@
             diskExpiryThreadIntervalSeconds="120"
             />
 
-    <!-- We want eternal="true" (with no timeToIdle or timeToLive settings) because Ki manages session
+    <!-- We want eternal="true" (with no timeToIdle or timeToLive settings) because Shiro manages session
 expirations explicitly.  If we set it to false and then set corresponding timeToIdle and timeToLive properties,
-ehcache would evict sessions without Ki's knowledge, which would cause many problems
-(e.g. "My Ki session timeout is 30 minutes - why isn't a session available after 2 minutes?"
+ehcache would evict sessions without Shiro's knowledge, which would cause many problems
+(e.g. "My Shiro session timeout is 30 minutes - why isn't a session available after 2 minutes?"
 Answer - ehcache expired it due to the timeToIdle property set to 120 seconds.)
 
 diskPersistent=true since we want an enterprise session management feature - ability to use sessions after
 even after a JVM restart.  -->
-    <!-- <cache name="ki-activeSessionCache"
+    <!-- <cache name="shiro-activeSessionCache"
    maxElementsInMemory="20000"
    eternal="true"
    overflowToDisk="true"
    diskPersistent="true"
    diskExpiryThreadIntervalSeconds="600"/> -->
 
-    <cache name="org.apache.ki.realm.text.PropertiesRealm-0-accounts"
+    <cache name="org.apache.shiro.realm.text.PropertiesRealm-0-accounts"
            maxElementsInMemory="1000"
            eternal="true"
            overflowToDisk="true"/>

Modified: incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/QuartzSessionValidationJob.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/QuartzSessionValidationJob.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/QuartzSessionValidationJob.java (original)
+++ incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/QuartzSessionValidationJob.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt.quartz;
+package org.apache.shiro.session.mgt.quartz;
 
 import org.quartz.Job;
 import org.quartz.JobDataMap;
@@ -26,10 +26,10 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.session.mgt.ValidatingSessionManager;
+import org.apache.shiro.session.mgt.ValidatingSessionManager;
 
 /**
- * A quartz job that basically just calls the {@link org.apache.ki.session.mgt.ValidatingSessionManager#validateSessions()}
+ * A quartz job that basically just calls the {@link org.apache.shiro.session.mgt.ValidatingSessionManager#validateSessions()}
  * method on a configured session manager.  The session manager will automatically be injected by the
  * superclass if it is in the job data map or the scheduler map.
  *

Modified: incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/QuartzSessionValidationScheduler.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/QuartzSessionValidationScheduler.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/package-info.java (original)
+++ incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/package-info.java Thu Jun 18 03:13:34 2009
@@ -21,4 +21,4 @@
  * components that help <tt>SessionManager</tt> implementations maintain sessions (timed expiration, orphan cleanup,
  * etc).
  */
-package org.apache.ki.session.mgt.quartz;
+package org.apache.shiro.session.mgt.quartz;

Modified: incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/LifecycleBeanPostProcessor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/LifecycleBeanPostProcessor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/SpringShiroFilter.java (added)
+++ incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/SpringShiroFilter.java Thu Jun 18 03:13:34 2009
@@ -0,0 +1,62 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.shiro.spring;
+
+import org.apache.shiro.web.servlet.ShiroFilter;
+
+
+/**
+ * Extension of KiFilter that uses {@link SpringIniWebConfiguration} to configure Shiro in a Spring web
+ * environment.
+ * <p/>
+ * Using this class in web.xml essentially enables the following:
+ * <pre>&lt;filter&gt;
+ * &lt;filter-name&gt;KiFilter&lt;/filter-name&gt;
+ * &lt;filter-class&gt;org.apache.shiro.web.servlet.KiFilter&lt;/filter-class&gt;
+ * &lt;init-param&gt;
+ *     &lt;param-name&gt;configClassName&lt;/param-name&gt;
+ *     &lt;param-value&gt;org.apache.shiro.spring.SpringIniWebConfiguration&lt;param-value&gt;
+ * &lt;/init-param&gt;
+ * &lt;init-param&gt;
+ *     &lt;param-name&gt;config&lt;/param-name&gt;
+ *     &lt;param-value&gt;
+ *     ... normal .ini config ...
+ *     &lt;param-value&gt;
+ * &lt;/init-param&gt;
+&lt;filter&gt;</pre>
+ * <p/>
+ * That is, you don't have to specify the additional <code>configClassName</code> <code>init-param</code>.
+ *
+ * @author Les Hazlewood
+ * @author Jeremy Haile
+ * @since 0.2
+ */
+public class SpringShiroFilter extends ShiroFilter
+{
+
+    //TODO - complete JavaDoc
+
+    /**
+     * Default constructor, merely calls
+     * <code>{@link #configClassName this.configClassName} = {@link SpringIniWebConfiguration SpringIniWebConfiguration}.class.getName()}</code>.
+     */
+    public SpringShiroFilter() {
+        this.configClassName = SpringIniWebConfiguration.class.getName();
+    }
+}

Modified: incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationExecutor.java (original)
+++ incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationExecutor.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.spring.remoting;
+package org.apache.shiro.spring.remoting;
 
 import java.io.Serializable;
 import java.lang.reflect.InvocationTargetException;
@@ -28,8 +28,8 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.mgt.SecurityManager;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.mgt.SecurityManager;
+import org.apache.shiro.util.ThreadContext;
 
 
 /**
@@ -69,7 +69,7 @@
     |  A C C E S S O R S / M O D I F I E R S    |
     ============================================*/
 
-    public void setSecurityManager(org.apache.ki.mgt.SecurityManager securityManager) {
+    public void setSecurityManager(org.apache.shiro.mgt.SecurityManager securityManager) {
         this.securityManager = securityManager;
     }
 
@@ -90,7 +90,7 @@
                 ThreadContext.bindSessionId(sessionId);
             } else {
                 if (log.isTraceEnabled()) {
-                    log.trace("RemoteInvocation did not contain a Ki Session id attribute under " +
+                    log.trace("RemoteInvocation did not contain a Shiro Session id attribute under " +
                             "key [" + SecureRemoteInvocationFactory.SESSION_ID_KEY + "].  A Subject based " +
                             "on an existing Session will not be available during the method invocatin.");
                 }

Modified: incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/standalone/src/main/java/MyRealm.java (original)
+++ incubator/shiro/trunk/samples/standalone/src/main/java/MyRealm.java Thu Jun 18 03:13:34 2009
@@ -17,10 +17,10 @@
  * under the License.
  */
 
-import org.apache.ki.authc.*;
-import org.apache.ki.authz.AuthorizationInfo;
-import org.apache.ki.realm.AuthorizingRealm;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.authc.*;
+import org.apache.shiro.authz.AuthorizationInfo;
+import org.apache.shiro.realm.AuthorizingRealm;
+import org.apache.shiro.subject.PrincipalCollection;
 
 /**
  * @author Les Hazlewood
@@ -36,10 +36,10 @@
      * an underlying data store via an EIS API (JDBC, JPA, Hibernate, etc).
      * <p/>
      * Note that when implementing your own realm, there is no need to check against a password (or other credentials)
      * in this method. The {@link org.apache.ki.realm.AuthenticatingRealm AuthenticatingRealm} superclass will do
      * that automatically via the use of a configured
      * {@link org.apache.ki.authc.credential.CredentialsMatcher CredentialsMatcher} (see this example's corresponding
      * {@code ki.ini} file to see a configured credentials matcher).
      * <p/>
      * All that is required is that the account information include directly the credentials found in the EIS.
      *
@@ -36,10 +36,10 @@
      * <p/>
      * Note that when implementing your own realm, there is no need to check against a password (or other credentials)
-     * in this method. The {@link org.apache.ki.realm.AuthenticatingRealm AuthenticatingRealm} superclass will do
+     * in this method. The {@link org.apache.shiro.realm.AuthenticatingRealm AuthenticatingRealm} superclass will do
      * that automatically via the use of a configured
@@ -36,10 +36,10 @@
      * that automatically via the use of a configured
-     * {@link org.apache.ki.authc.credential.CredentialsMatcher CredentialsMatcher} (see this example's corresponding
-     * {@code ki.ini} file to see a configured credentials matcher).
+     * {@link org.apache.shiro.authc.credential.CredentialsMatcher CredentialsMatcher} (see this example's corresponding
+     * {@code shiro.ini} file to see a configured credentials matcher).
      * <p/>
      * All that is required is that the account information include directly the credentials found in the EIS.

Modified: incubator/shiro/trunk/samples/standalone/src/main/java/Standalone.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/standalone/src/main/java/Standalone.java?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/samples/standalone/src/main/java/Standalone.java (original)
+++ incubator/shiro/trunk/samples/standalone/src/main/java/Standalone.java Thu Jun 18 03:13:34 2009
@@ -17,9 +17,9 @@
  * under the License.
  */
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.config.IniConfiguration;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.config.IniConfiguration;
+import org.apache.shiro.subject.Subject;
 
 /**
  * @author Les Hazlewood
@@ -30,7 +30,7 @@
     public static void main(String[] args) {
 
         IniConfiguration config = new IniConfiguration();
         //the following call will automatically use ki.ini at the root of the classpath:
         config.init();
 
         //This is for Standalone (single-VM) applications that don't use a configuration container (Spring, JBoss, etc)
@@ -30,7 +30,7 @@
 
         IniConfiguration config = new IniConfiguration();
-        //the following call will automatically use ki.ini at the root of the classpath:
+        //the following call will automatically use shiro.ini at the root of the classpath:
         config.init();
 

Modified: incubator/shiro/trunk/samples/standalone/src/main/resources/log4j.properties
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/samples/standalone/src/main/resources/log4j.properties?rev=785881&r1=785880&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/EhCache.java (original)
+++ incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/EhCache.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache.ehcache;
+package org.apache.shiro.cache.ehcache;
 
 import java.util.Collections;
 import java.util.LinkedHashSet;
@@ -28,11 +28,11 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.cache.Cache;
-import org.apache.ki.cache.CacheException;
+import org.apache.shiro.cache.Cache;
+import org.apache.shiro.cache.CacheException;
 
 /**
  * Ki {@link org.apache.ki.cache.Cache} implementation that wraps an {@link net.sf.ehcache.Ehcache} instance.
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
@@ -52,7 +52,7 @@
     /**
      * Constructs a new EhCache instance with the given cache.
      *
      * @param cache - delegate EhCache instance this Ki cache instance will wrap.
      */
     public EhCache(net.sf.ehcache.Cache cache) {
         if (cache == null) {
@@ -28,11 +28,11 @@
 
 /**
- * Ki {@link org.apache.ki.cache.Cache} implementation that wraps an {@link net.sf.ehcache.Ehcache} instance.
+ * Shiro {@link org.apache.shiro.cache.Cache} implementation that wraps an {@link net.sf.ehcache.Ehcache} instance.
  *
  * @author Jeremy Haile
@@ -52,7 +52,7 @@
      * Constructs a new EhCache instance with the given cache.
      *
-     * @param cache - delegate EhCache instance this Ki cache instance will wrap.
+     * @param cache - delegate EhCache instance this Shiro cache instance will wrap.
      */
     public EhCache(net.sf.ehcache.Cache cache) {

Modified: incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/EhCacheManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/EhCacheManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/EhCacheManager.java (original)
+++ incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/EhCacheManager.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.cache.ehcache;
+package org.apache.shiro.cache.ehcache;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -24,21 +24,21 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.cache.Cache;
-import org.apache.ki.cache.CacheException;
-import org.apache.ki.cache.CacheManager;
-import org.apache.ki.io.ResourceUtils;
-import org.apache.ki.session.mgt.eis.CachingSessionDAO;
-import org.apache.ki.util.Destroyable;
-import org.apache.ki.util.Initializable;
+import org.apache.shiro.cache.Cache;
+import org.apache.shiro.cache.CacheException;
+import org.apache.shiro.cache.CacheManager;
+import org.apache.shiro.io.ResourceUtils;
+import org.apache.shiro.session.mgt.eis.CachingSessionDAO;
+import org.apache.shiro.util.Destroyable;
+import org.apache.shiro.util.Initializable;
 
 /**
  * Ki <code>CacheManager</code> implementation utilizing the Ehcache framework for all cache functionality.
  * <p/>
  * This class can {@link #setCacheManager(net.sf.ehcache.CacheManager) accept} a manually configured
  * {@link net.sf.ehcache.CacheManager net.sf.ehcache.CacheManager} instance,
  * or an <code>ehcache.xml</code> path location can be specified instead and one will be constructed. If neither are
  * specified, Ki's failsafe <code><a href="./ehcache.xml">ehcache.xml</a></code> file will be used by default.
  *
  * <p>This implementation requires EhCache 1.2 and above. Make sure EhCache 1.1 or earlier
  * is not in the classpath or it will not work.</p>
@@ -54,7 +54,7 @@
 
     /**
      * The default name for the active sessions cache, equal to
-     * {@link org.apache.ki.session.mgt.eis.CachingSessionDAO#ACTIVE_SESSION_CACHE_NAME CachingSessionDAO.ACTIVE_SESSION_CACHE_NAME}.
+     * {@link org.apache.shiro.session.mgt.eis.CachingSessionDAO#ACTIVE_SESSION_CACHE_NAME CachingSessionDAO.ACTIVE_SESSION_CACHE_NAME}.
      */
     public static final String DEFAULT_ACTIVE_SESSIONS_CACHE_NAME = CachingSessionDAO.ACTIVE_SESSION_CACHE_NAME;
 
@@ -87,7 +87,7 @@
     /**
      * Classpath file location of the ehcache CacheManager config file.
      */
-    private String cacheManagerConfigFile = "classpath:org/ki/cache/ehcache/ehcache.xml";
+    private String cacheManagerConfigFile = "classpath:org/shiro/cache/ehcache/ehcache.xml";
 
     /**
      * Default no argument constructor
@@ -116,7 +116,7 @@
     /**
      * Returns the resource location of the config file used to initialize a new
      * EhCache CacheManager instance.  The string can be any resource path supported by the
-     * {@link org.apache.ki.io.ResourceUtils#getInputStreamForPath(String)} call.
+     * {@link org.apache.shiro.io.ResourceUtils#getInputStreamForPath(String)} call.
      *
      * <p>This property is ignored if the CacheManager instance is injected directly - that is, it is only used to
      * lazily create a CacheManager if one is not already provided.</p>
@@ -131,7 +131,7 @@
     /**
      * Sets the resource location of the config file used to initialize the wrapped
      * EhCache CacheManager instance.  The string can be any resource path supported by the
-     * {@link org.apache.ki.io.ResourceUtils#getInputStreamForPath(String)} call.
+     * {@link org.apache.shiro.io.ResourceUtils#getInputStreamForPath(String)} call.
      *
      * <p>This property is ignored if the CacheManager instance is injected directly - that is, it is only used to
      * lazily create a CacheManager if one is not already provided.</p>
@@ -178,7 +178,7 @@
                 }
                 if (name.equals(DEFAULT_ACTIVE_SESSIONS_CACHE_NAME)) {
                     if (log.isInfoEnabled()) {
-                        log.info("Creating " + DEFAULT_ACTIVE_SESSIONS_CACHE_NAME + " cache with default Ki " +
+                        log.info("Creating " + DEFAULT_ACTIVE_SESSIONS_CACHE_NAME + " cache with default Shiro " +
                                 "session cache settings.");
                     }
                     cache = buildDefaultActiveSessionsCache();
@@ -204,10 +204,10 @@
     }
 
     /**
      * Builds the default cache instance to use for Ki's Session Cache when enterprise Sessions are
      * enabled.
      *
      * @return the default cache instance to use for Ki's Session Cache when enterprise Sessions are
      *         enabled.
      * @throws CacheException if there is a problem constructing the Cache instance.
      */
@@ -233,11 +233,11 @@
      * Ehcache will look for an <tt>ehcache.xml</tt> file at the root of the classpath.  If one is not found,
      * Ehcache will use its own failsafe configuration file.</p>
      *
      * <p>Because Ki cannot use the failsafe defaults (failsafe expunges cached objects after 2 minutes,
      * something not desireable for Ki sessions), this class manages an internal default configuration for
      * this case.</p>
      *
-     * @throws org.apache.ki.cache.CacheException
+     * @throws org.apache.shiro.cache.CacheException
      *          if there are any CacheExceptions thrown by EhCache.
      * @see net.sf.ehcache.CacheManager#create
      */
@@ -24,21 +24,21 @@
 
 /**
- * Ki <code>CacheManager</code> implementation utilizing the Ehcache framework for all cache functionality.
+ * Shiro <code>CacheManager</code> implementation utilizing the Ehcache framework for all cache functionality.
  * <p/>
  * This class can {@link #setCacheManager(net.sf.ehcache.CacheManager) accept} a manually configured
@@ -24,21 +24,21 @@
  * {@link net.sf.ehcache.CacheManager net.sf.ehcache.CacheManager} instance,
  * or an <code>ehcache.xml</code> path location can be specified instead and one will be constructed. If neither are
- * specified, Ki's failsafe <code><a href="./ehcache.xml">ehcache.xml</a></code> file will be used by default.
+ * specified, Shiro's failsafe <code><a href="./ehcache.xml">ehcache.xml</a></code> file will be used by default.
  *
  * <p>This implementation requires EhCache 1.2 and above. Make sure EhCache 1.1 or earlier
@@ -204,10 +204,10 @@
 
     /**
-     * Builds the default cache instance to use for Ki's Session Cache when enterprise Sessions are
+     * Builds the default cache instance to use for Shiro's Session Cache when enterprise Sessions are
      * enabled.
      *
@@ -204,10 +204,10 @@
      * enabled.
      *
-     * @return the default cache instance to use for Ki's Session Cache when enterprise Sessions are
+     * @return the default cache instance to use for Shiro's Session Cache when enterprise Sessions are
      *         enabled.
      * @throws CacheException if there is a problem constructing the Cache instance.
@@ -233,11 +233,11 @@
      * Ehcache will use its own failsafe configuration file.</p>
      *
-     * <p>Because Ki cannot use the failsafe defaults (failsafe expunges cached objects after 2 minutes,
-     * something not desireable for Ki sessions), this class manages an internal default configuration for
+     * <p>Because Shiro cannot use the failsafe defaults (failsafe expunges cached objects after 2 minutes,
+     * something not desireable for Shiro sessions), this class manages an internal default configuration for
      * this case.</p>
      *

Modified: incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/ehcache/src/main/java/org/apache/shiro/cache/ehcache/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/QuartzSessionValidationScheduler.java (original)
+++ incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/QuartzSessionValidationScheduler.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.session.mgt.quartz;
+package org.apache.shiro.session.mgt.quartz;
 
 import org.quartz.JobDetail;
 import org.quartz.Scheduler;
@@ -27,14 +27,14 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.session.mgt.DefaultSessionManager;
-import org.apache.ki.session.mgt.SessionValidationScheduler;
-import org.apache.ki.session.mgt.ValidatingSessionManager;
+import org.apache.shiro.session.mgt.DefaultSessionManager;
+import org.apache.shiro.session.mgt.SessionValidationScheduler;
+import org.apache.shiro.session.mgt.ValidatingSessionManager;
 
 
 /**
  * An implementation of the {@link org.apache.ki.session.mgt.SessionValidationScheduler SessionValidationScheduler} that uses Quartz to schedule a
  * job to call {@link org.apache.ki.session.mgt.ValidatingSessionManager#validateSessions()} on
  * a regular basis.
  *
  * @author Jeremy Haile
@@ -129,7 +129,7 @@
 
     /**
      * Specifies how frequently (in milliseconds) this Scheduler will call the
-     * {@link org.apache.ki.session.mgt.ValidatingSessionManager#validateSessions() ValidatingSessionManager#validateSessions()} method.
+     * {@link org.apache.shiro.session.mgt.ValidatingSessionManager#validateSessions() ValidatingSessionManager#validateSessions()} method.
      *
      * <p>Unless this method is called, the default value is {@link #DEFAULT_SESSION_VALIDATION_INTERVAL}.
      *
@@ -27,14 +27,14 @@
 
 /**
- * An implementation of the {@link org.apache.ki.session.mgt.SessionValidationScheduler SessionValidationScheduler} that uses Quartz to schedule a
- * job to call {@link org.apache.ki.session.mgt.ValidatingSessionManager#validateSessions()} on
+ * An implementation of the {@link org.apache.shiro.session.mgt.SessionValidationScheduler SessionValidationScheduler} that uses Quartz to schedule a
+ * job to call {@link org.apache.shiro.session.mgt.ValidatingSessionManager#validateSessions()} on
  * a regular basis.
  *

Modified: incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/quartz/src/main/java/org/apache/shiro/session/mgt/quartz/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/LifecycleBeanPostProcessor.java (original)
+++ incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/LifecycleBeanPostProcessor.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.spring;
+package org.apache.shiro.spring;
 
 import org.springframework.beans.BeansException;
 import org.springframework.beans.FatalBeanException;
@@ -25,15 +25,15 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.util.Destroyable;
-import org.apache.ki.util.Initializable;
+import org.apache.shiro.util.Destroyable;
+import org.apache.shiro.util.Initializable;
 
 
 /**
  * <p>Bean post processor for Spring that automatically calls the <tt>init()</tt> and/or
  * <tt>destroy()</tt> methods on Ki objects that implement the {@link org.apache.ki.util.Initializable}
  * or {@link org.apache.ki.util.Destroyable} interfaces, respectfully.  This post processor makes it easier
  * to configure Ki beans in Spring, since the user never has to worry about whether or not if they
  * have to specify init-method and destroy-method bean attributes.</p>
  *
  * <p><b>Warning: This post processor has no way to determine if <tt>init()</tt> or <tt>destroy()</tt> have
@@ -51,7 +51,7 @@
     private static final Logger log = LoggerFactory.getLogger(LifecycleBeanPostProcessor.class);
 
     /**
-     * Calls the <tt>init()</tt> methods on the bean if it implements {@link org.apache.ki.util.Initializable}
+     * Calls the <tt>init()</tt> methods on the bean if it implements {@link org.apache.shiro.util.Initializable}
      *
      * @param object the object being initialized.
      * @param name   the name of the bean being initialized.
@@ -84,7 +84,7 @@
 
 
     /**
-     * Calls the <tt>destroy()</tt> methods on the bean if it implements {@link org.apache.ki.util.Destroyable}
+     * Calls the <tt>destroy()</tt> methods on the bean if it implements {@link org.apache.shiro.util.Destroyable}
      *
      * @param object the object being initialized.
      * @param name   the name of the bean being initialized.
@@ -25,15 +25,15 @@
 /**
  * <p>Bean post processor for Spring that automatically calls the <tt>init()</tt> and/or
- * <tt>destroy()</tt> methods on Ki objects that implement the {@link org.apache.ki.util.Initializable}
- * or {@link org.apache.ki.util.Destroyable} interfaces, respectfully.  This post processor makes it easier
- * to configure Ki beans in Spring, since the user never has to worry about whether or not if they
+ * <tt>destroy()</tt> methods on Shiro objects that implement the {@link org.apache.shiro.util.Initializable}
+ * or {@link org.apache.shiro.util.Destroyable} interfaces, respectfully.  This post processor makes it easier
+ * to configure Shiro beans in Spring, since the user never has to worry about whether or not if they
  * have to specify init-method and destroy-method bean attributes.</p>
  *

Modified: incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/SpringIniWebConfiguration.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/SpringIniWebConfiguration.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/SpringIniWebConfiguration.java (original)
+++ incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/SpringIniWebConfiguration.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.spring;
+package org.apache.shiro.spring;
 
 import java.util.Collection;
 import java.util.Map;
@@ -29,26 +29,26 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.KiException;
-import org.apache.ki.mgt.RealmSecurityManager;
-import org.apache.ki.mgt.SecurityManager;
-import org.apache.ki.realm.Realm;
-import org.apache.ki.web.config.IniWebConfiguration;
+import org.apache.shiro.ShiroException;
+import org.apache.shiro.mgt.RealmSecurityManager;
+import org.apache.shiro.mgt.SecurityManager;
+import org.apache.shiro.realm.Realm;
+import org.apache.shiro.web.config.IniWebConfiguration;
 
 
 /**
  * <p>Ki configuration that relies on Spring to define and initialize the Ki SecurityManager
  * instance (and all of its dependencies) and makes it available to the KiFilter by performing a Spring bean
  * lookup.  The URL/filter definitions are still .ini based and loaded according to the behavior of the parent class
- * {@link org.apache.ki.web.config.IniWebConfiguration}</p>
+ * {@link org.apache.shiro.web.config.IniWebConfiguration}</p>
  * <p/>
  * That is, this class is offers a hybrid means of configuring Ki in Spring apps deployed in a web container:
  * Spring XML config for the SecurityManager and its dependencies (realms, etc), and .ini format for configuring
  * the filters and the url chains in web.xml, which many people like to maintain separation of concerns:
  * the web/filter/url config stays in web.xml, whereas the SecurityManager config (really a business-tier concern)
  * stays in Spring .xml files.
  * <p/>
  * The behavior used to acquire the Ki <code>SecurityManager</code> is as follows:
  * <ol>
  * <li>If a 'securityManagerBeanName' init-param is set, retrieve that sec manager from Spring.</li>
  * <li>If not, look for beans of type {@link SecurityManager} - if there is one instance, use that.
@@ -56,7 +56,7 @@
  * throw an exception that says you have to set the init-param to specify the bean name.</li>
  * <li>if no beans of type {@link SecurityManager}, look for any beans of type {@link Realm}.
  * If some are found, create a default security manager by calling
- * {@link org.apache.ki.web.config.IniWebConfiguration#createSecurityManager(java.util.Map) super.createSecurityManager(Map)}
+ * {@link org.apache.shiro.web.config.IniWebConfiguration#createSecurityManager(java.util.Map) super.createSecurityManager(Map)}
  * and set the Realms on that SecurityManager instance.</li>
  * <li>If none of the above, throw an exception that explains the options.</li>
  * <ol>
@@ -89,7 +89,8 @@
     }
 
     @Override
-    public void init() throws KiException {
+    public void init() throws ShiroException
+    {
         String beanName = getFilterConfig().getInitParameter(SECURITY_MANAGER_BEAN_NAME_PARAM_NAME);
         if (beanName != null) {
             setSecurityManagerBeanName(beanName);
@@ -115,7 +116,7 @@
 
         SecurityManager securityManager = null;
         if (beanName != null) {
-            securityManager = (SecurityManager) appCtx.getBean(beanName, org.apache.ki.mgt.SecurityManager.class);
+            securityManager = (SecurityManager) appCtx.getBean(beanName, org.apache.shiro.mgt.SecurityManager.class);
         }
 
         if (securityManager == null) {
@@ -29,26 +29,26 @@
 
 /**
- * <p>Ki configuration that relies on Spring to define and initialize the Ki SecurityManager
+ * <p>Shiro configuration that relies on Spring to define and initialize the Shiro SecurityManager
  * instance (and all of its dependencies) and makes it available to the KiFilter by performing a Spring bean
  * lookup.  The URL/filter definitions are still .ini based and loaded according to the behavior of the parent class
@@ -29,26 +29,26 @@
  * <p/>
- * That is, this class is offers a hybrid means of configuring Ki in Spring apps deployed in a web container:
+ * That is, this class is offers a hybrid means of configuring Shiro in Spring apps deployed in a web container:
  * Spring XML config for the SecurityManager and its dependencies (realms, etc), and .ini format for configuring
  * the filters and the url chains in web.xml, which many people like to maintain separation of concerns:
@@ -29,26 +29,26 @@
  * stays in Spring .xml files.
  * <p/>
- * The behavior used to acquire the Ki <code>SecurityManager</code> is as follows:
+ * The behavior used to acquire the Shiro <code>SecurityManager</code> is as follows:
  * <ol>
  * <li>If a 'securityManagerBeanName' init-param is set, retrieve that sec manager from Spring.</li>

Added: incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/SpringShiroFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/SpringShiroFilter.java?rev=785881&view=auto
==============================================================================
--- incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/package-info.java (original)
+++ incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/package-info.java Thu Jun 18 03:13:34 2009
@@ -18,6 +18,6 @@
  */
 /**
  * <a href="http://www.springframework.org" target="_top">Spring Application Framework</a> support for enabling
  * Ki in spring applications.
  */
-package org.apache.ki.spring;
+package org.apache.shiro.spring;
@@ -18,6 +18,6 @@
 /**
  * <a href="http://www.springframework.org" target="_top">Spring Application Framework</a> support for enabling
- * Ki in spring applications.
+ * Shiro in spring applications.
  */

Modified: incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationExecutor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationExecutor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationFactory.java (original)
+++ incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationFactory.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.spring.remoting;
+package org.apache.shiro.spring.remoting;
 
 import java.io.Serializable;
 import java.net.InetAddress;
@@ -29,18 +29,18 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.util.ThreadContext;
-import org.apache.ki.session.Session;
-import org.apache.ki.session.mgt.SessionManager;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.util.ThreadContext;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.session.mgt.SessionManager;
+import org.apache.shiro.subject.Subject;
 
 
 /**
  * A {@link RemoteInvocationFactory} that passes the session ID to the server via a
  * {@link RemoteInvocation} {@link RemoteInvocation#getAttribute(String) attribute}.
  * This factory is the client-side part of
  * the Ki Spring remoting invocation.  A {@link SecureRemoteInvocationExecutor} should
  * be used to export the server-side remote services to ensure that the appropriate
  * Subject and Session are bound to the remote thread during execution.
  *
@@ -55,7 +55,7 @@
     public static final String SESSION_ID_KEY = Session.class.getName() + "_ID_KEY";
     public static final String INET_ADDRESS_KEY = InetAddress.class.getName() + "_KEY";
 
-    private static final String SESSION_ID_SYSTEM_PROPERTY_NAME = "ki.session.id";
+    private static final String SESSION_ID_SYSTEM_PROPERTY_NAME = "shiro.session.id";
 
     /**
      * Creates a {@link RemoteInvocation} with the current session ID as an
@@ -97,11 +97,11 @@
         if (sessionId == null) {
             if (log.isTraceEnabled()) {
                 log.trace("No Session found for the currently executing subject via subject.getSession(false).  " +
-                    "Attempting to revert back to the 'ki.session.id' system property...");
+                    "Attempting to revert back to the 'shiro.session.id' system property...");
             }
             sessionId = System.getProperty(SESSION_ID_SYSTEM_PROPERTY_NAME);
             if (sessionId == null && log.isTraceEnabled()) {
-                log.trace("No 'ki.session.id' system property found.  Heuristics have been exhausted; " +
+                log.trace("No 'shiro.session.id' system property found.  Heuristics have been exhausted; " +
                     "RemoteInvocation will not contain a sessionId.");
             }
         }
@@ -29,18 +29,18 @@
  * {@link RemoteInvocation} {@link RemoteInvocation#getAttribute(String) attribute}.
  * This factory is the client-side part of
- * the Ki Spring remoting invocation.  A {@link SecureRemoteInvocationExecutor} should
+ * the Shiro Spring remoting invocation.  A {@link SecureRemoteInvocationExecutor} should
  * be used to export the server-side remote services to ensure that the appropriate
  * Subject and Session are bound to the remote thread during execution.

Modified: incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/package-info.java (original)
+++ incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/remoting/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,7 +17,7 @@
  * under the License.
  */
 /**
  * Support to enable Spring-based remote method invocations to carry a Ki session ID as part of the
  * invocation payload, allowing remote clients to perform security operations.
  */
-package org.apache.ki.spring.remoting;
+package org.apache.shiro.spring.remoting;
@@ -17,7 +17,7 @@
  */
 /**
- * Support to enable Spring-based remote method invocations to carry a Ki session ID as part of the
+ * Support to enable Spring-based remote method invocations to carry a Shiro session ID as part of the
  * invocation payload, allowing remote clients to perform security operations.
  */

Modified: incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/AopAllianceAnnotationsAuthorizingMethodInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/AopAllianceAnnotationsAuthorizingMethodInterceptor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/AopAllianceAnnotationsAuthorizingMethodInterceptor.java (original)
+++ incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/AopAllianceAnnotationsAuthorizingMethodInterceptor.java Thu Jun 18 03:13:34 2009
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.spring.security.interceptor;
+package org.apache.shiro.spring.security.interceptor;
 
 import java.lang.reflect.Method;
 
 import org.aopalliance.intercept.MethodInterceptor;
 import org.aopalliance.intercept.MethodInvocation;
 
-import org.apache.ki.authz.aop.AnnotationsAuthorizingMethodInterceptor;
+import org.apache.shiro.authz.aop.AnnotationsAuthorizingMethodInterceptor;
 
 /**
- * Allows Ki Annotations to work in any <a href="http://aopalliance.sourceforge.net/">AOP Alliance</a>
+ * Allows Shiro Annotations to work in any <a href="http://aopalliance.sourceforge.net/">AOP Alliance</a>
  * specific implementation environment (for example, Spring).
  *
  * @author Les Hazlewood
@@ -38,16 +38,16 @@
     /**
      * Creates a {@link MethodInvocation MethodInvocation} that wraps an
      * {@link org.aopalliance.intercept.MethodInvocation org.aopalliance.intercept.MethodInvocation} instance,
-     * enabling Ki Annotations in <a href="http://aopalliance.sourceforge.net/">AOP Alliance</a> environments
+     * enabling Shiro Annotations in <a href="http://aopalliance.sourceforge.net/">AOP Alliance</a> environments
      * (Spring, etc).
      *
      * @param implSpecificMethodInvocation AOP Alliance {@link org.aopalliance.intercept.MethodInvocation MethodInvocation}
      * @return a Ki {@link MethodInvocation MethodInvocation} instance that wraps the AOP Alliance instance.
      */
-    protected org.apache.ki.aop.MethodInvocation createMethodInvocation(Object implSpecificMethodInvocation) {
+    protected org.apache.shiro.aop.MethodInvocation createMethodInvocation(Object implSpecificMethodInvocation) {
         final MethodInvocation mi = (MethodInvocation) implSpecificMethodInvocation;
 
-        return new org.apache.ki.aop.MethodInvocation() {
+        return new org.apache.shiro.aop.MethodInvocation() {
             public Method getMethod() {
                 return mi.getMethod();
             }
@@ -80,15 +80,15 @@
     }
 
     /**
      * Creates a Ki {@link MethodInvocation MethodInvocation} instance and then immediately calls
      * {@link org.apache.ki.authz.aop.AuthorizingMethodInterceptor#invoke super.invoke}.
      *
      * @param methodInvocation the AOP Alliance-specific <code>methodInvocation</code> instance.
      * @return the return value from invoking the method invocation.
      * @throws Throwable if the underlying AOP Alliance method invocation throws a <code>Throwable</code>.
      */
     public Object invoke(MethodInvocation methodInvocation) throws Throwable {
-        org.apache.ki.aop.MethodInvocation mi = createMethodInvocation(methodInvocation);
+        org.apache.shiro.aop.MethodInvocation mi = createMethodInvocation(methodInvocation);
         return super.invoke(mi);
     }
 }
@@ -38,16 +38,16 @@
      *
      * @param implSpecificMethodInvocation AOP Alliance {@link org.aopalliance.intercept.MethodInvocation MethodInvocation}
-     * @return a Ki {@link MethodInvocation MethodInvocation} instance that wraps the AOP Alliance instance.
+     * @return a Shiro {@link MethodInvocation MethodInvocation} instance that wraps the AOP Alliance instance.
      */
@@ -80,15 +80,15 @@
 
     /**
-     * Creates a Ki {@link MethodInvocation MethodInvocation} instance and then immediately calls
-     * {@link org.apache.ki.authz.aop.AuthorizingMethodInterceptor#invoke super.invoke}.
+     * Creates a Shiro {@link MethodInvocation MethodInvocation} instance and then immediately calls
+     * {@link org.apache.shiro.authz.aop.AuthorizingMethodInterceptor#invoke super.invoke}.
      *
      * @param methodInvocation the AOP Alliance-specific <code>methodInvocation</code> instance.